analphipy.Phi\_lj
=================

.. currentmodule:: analphipy

.. autoclass:: Phi_lj

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Phi_lj.__init__
      ~Phi_lj.asdict
      ~Phi_lj.assign
      ~Phi_lj.assign_min_numeric
      ~Phi_lj.cut
      ~Phi_lj.dphidr
      ~Phi_lj.lfs
      ~Phi_lj.minimize
      ~Phi_lj.new_like
      ~Phi_lj.phi
      ~Phi_lj.to_measures
      ~Phi_lj.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~Phi_lj.sig
      ~Phi_lj.eps
      ~Phi_lj.phi_min
      ~Phi_lj.r_min
      ~Phi_lj.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Phi_lj.__repr__
   
   